==> qmmp_0.4.1.orig.tar.gz: qmmp-0.4.1/src/qmmpui/translations/libqmmpui_uk_UA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk">
<context>
    <name>DetailsDialog</name>
    <message>
        <location filename="../detailsdialog.cpp" line="81"/>
        <source>Title</source>
        <translation>Заголовок</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="82"/>
        <source>Artist</source>
        <translation>Виконавець</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="83"/>
        <source>Album</source>
        <translation>Альбом</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="84"/>
        <source>Comment</source>
        <translation>Коментар</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="85"/>
        <source>Genre</source>
        <translation>Жанр</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="86"/>
        <source>Composer</source>
        <translation>Композитор</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="88"/>
        <source>Year</source>
        <translation>Рік</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="90"/>
        <source>Track</source>
        <translation>Доріжка</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="92"/>
        <source>Disc number</source>
        <translation>Номер диску</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="14"/>
        <source>Details</source>
        <translation>Подробиці</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="46"/>
        <source>Summary</source>
        <translation>Підсумок</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="55"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Arial&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>PlayListManager</name>
    <message>
        <location filename="../playlistmanager.cpp" line="115"/>
        <location filename="../playlistmanager.cpp" line="350"/>
        <source>Playlist</source>
        <translation>Список</translation>
    </message>
</context>
<context>
    <name>QtFileDialogFactory</name>
    <message>
        <location filename="../qtfiledialog.cpp" line="33"/>
        <source>Qt File Dialog</source>
        <translation>Файловий діалог Qt</translation>
    </message>
</context>
<context>
    <name>TagEditor</name>
    <message>
        <location filename="../tageditor.ui" line="38"/>
        <source>Title:</source>
        <translation>Заголовок:</translation>
    </message>
    <message>
        <location filename="../tageditor.ui" line="64"/>
        <source>Artist:</source>
        <translation>Виконавець:</translation>
    </message>
    <message>
        <location filename="../tageditor.ui" line="90"/>
        <source>Album:</source>
        <translation>Альбом:</translation>
    </message>
    <message>
        <location filename="../tageditor.ui" line="113"/>
        <source>Composer:</source>
        <translation>Композитор:</translation>
    </message>
    <message>
        <location filename="../tageditor.ui" line="133"/>
        <source>Genre:</source>
        <translation>Жанр:</translation>
    </message>
    <message>
        <location filename="../tageditor.ui" line="159"/>
        <source>Disc number:</source>
        <translation>Номер диску:</translation>
    </message>
    <message>
        <location filename="../tageditor.ui" line="169"/>
        <location filename="../tageditor.ui" line="224"/>
        <location filename="../tageditor.ui" line="240"/>
        <source>?</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tageditor.ui" line="275"/>
        <source>Track:</source>
        <translation>Доріжка:</translation>
    </message>
    <message>
        <location filename="../tageditor.ui" line="259"/>
        <source>Year:</source>
        <translation>Рік:</translation>
    </message>
    <message>
        <location filename="../tageditor.ui" line="14"/>
        <source>Tag Editor</source>
        <translation>Редактор тегів</translation>
    </message>
    <message>
        <location filename="../tageditor.ui" line="182"/>
        <source>Comment:</source>
        <translation>Коментар:</translation>
    </message>
    <message>
        <location filename="../tageditor.ui" line="204"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Arial&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tageditor.ui" line="288"/>
        <source>Include selected tag in file</source>
        <translation>Включити вибраний тег у файл</translation>
    </message>
</context>
<context>
    <name>TemplateEditor</name>
    <message>
        <location filename="../templateeditor.ui" line="39"/>
        <source>Reset</source>
        <translation>Скинути</translation>
    </message>
    <message>
        <location filename="../templateeditor.ui" line="46"/>
        <source>Insert</source>
        <translation>Вставити</translation>
    </message>
    <message>
        <location filename="../templateeditor.ui" line="14"/>
        <source>Template Editor</source>
        <translation>Редактор шаблонів</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="50"/>
        <source>Artist</source>
        <translation>Виконавець</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="51"/>
        <source>Album</source>
        <translation>Альбом</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="52"/>
        <source>Title</source>
        <translation>Заголовок</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="53"/>
        <source>Track number</source>
        <translation>Номер треку</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="54"/>
        <source>Two-digit track number</source>
        <translation>2-розрядний номер треку</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="55"/>
        <source>Genre</source>
        <translation>Жанр</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="56"/>
        <source>Comment</source>
        <translation>Коментар</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="57"/>
        <source>Composer</source>
        <translation>Композитор</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="58"/>
        <source>Duration</source>
        <translation>Тривалість</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="59"/>
        <source>Disc number</source>
        <translation>Номер диску</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="60"/>
        <source>File name</source>
        <translation>Ім&apos;я файла</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="61"/>
        <source>File path</source>
        <translation>Шлях до файла</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="62"/>
        <source>Year</source>
        <translation>Рік</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="63"/>
        <source>Condition</source>
        <translation>Умова</translation>
    </message>
</context>
</TS>

==> qmmp_0.5.4.orig.tar.gz: qmmp-0.5.4/src/qmmpui/translations/libqmmpui_uk_UA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk">
<context>
    <name>DetailsDialog</name>
    <message>
        <location filename="../detailsdialog.cpp" line="105"/>
        <source>Title</source>
        <translation>Заголовок</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="106"/>
        <source>Artist</source>
        <translation>Виконавець</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="107"/>
        <source>Album</source>
        <translation>Альбом</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="108"/>
        <source>Comment</source>
        <translation>Коментар</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="109"/>
        <source>Genre</source>
        <translation>Жанр</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="110"/>
        <source>Composer</source>
        <translation>Композитор</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="112"/>
        <source>Year</source>
        <translation>Рік</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="114"/>
        <source>Track</source>
        <translation>Доріжка</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="116"/>
        <source>Disc number</source>
        <translation>Номер диску</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="14"/>
        <source>Details</source>
        <translation>Подробиці</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="42"/>
        <source>Open the directory containing this file</source>
        <translation>Відкрити теку, яка містить цей файл</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="45"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="59"/>
        <source>Summary</source>
        <translation>Підсумок</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="71"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Arial&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>PlayListManager</name>
    <message>
        <location filename="../playlistmanager.cpp" line="130"/>
        <location filename="../playlistmanager.cpp" line="365"/>
        <source>Playlist</source>
        <translation>Список</translation>
    </message>
</context>
<context>
    <name>QtFileDialogFactory</name>
    <message>
        <location filename="../qtfiledialog.cpp" line="34"/>
        <source>Qt File Dialog</source>
        <translation>Файловий діалог Qt</translation>
    </message>
</context>
<context>
    <name>TagEditor</name>
    <message>
        <location filename="../tageditor.ui" line="38"/>
        <source>Title:</source>
        <translation>Заголовок:</translation>
    </message>
    <message>
        <location filename="../tageditor.ui" line="64"/>
        <source>Artist:</source>
        <translation>Виконавець:</translation>
    </message>
    <message>
        <location filename="../tageditor.ui" line="90"/>
        <source>Album:</source>
        <translation>Альбом:</translation>
    </message>
    <message>
        <location filename="../tageditor.ui" line="113"/>
        <source>Composer:</source>
        <translation>Композитор:</translation>
    </message>
    <message>
        <location filename="../tageditor.ui" line="133"/>
        <source>Genre:</source>
        <translation>Жанр:</translation>
    </message>
    <message>
        <location filename="../tageditor.ui" line="244"/>
        <source>Disc number:</source>
        <translation>Номер диску:</translation>
    </message>
    <message>
        <location filename="../tageditor.ui" line="184"/>
        <location filename="../tageditor.ui" line="222"/>
        <location filename="../tageditor.ui" line="254"/>
        <source>?</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tageditor.ui" line="163"/>
        <source>Track:</source>
        <translation>Доріжка:</translation>
    </message>
    <message>
        <location filename="../tageditor.ui" line="197"/>
        <source>Year:</source>
        <translation>Рік:</translation>
    </message>
    <message>
        <location filename="../tageditor.ui" line="14"/>
        <source>Tag Editor</source>
        <translation>Редактор тегів</translation>
    </message>
    <message>
        <location filename="../tageditor.ui" line="269"/>
        <source>Comment:</source>
        <translation>Коментар:</translation>
    </message>
    <message>
        <location filename="../tageditor.ui" line="291"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Arial&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot;-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../tageditor.ui" line="305"/>
        <source>Include selected tag in file</source>
        <translation>Включити вибраний тег у файл</translation>
    </message>
</context>
<context>
    <name>TemplateEditor</name>
    <message>
        <location filename="../templateeditor.ui" line="39"/>
        <source>Reset</source>
        <translation>Скинути</translation>
    </message>
    <message>
        <location filename="../templateeditor.ui" line="46"/>
        <source>Insert</source>
        <translation>Вставити</translation>
    </message>
    <message>
        <location filename="../templateeditor.ui" line="14"/>
        <source>Template Editor</source>
        <translation>Редактор шаблонів</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="50"/>
        <source>Artist</source>
        <translation>Виконавець</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="51"/>
        <source>Album</source>
        <translation>Альбом</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="52"/>
        <source>Title</source>
        <translation>Заголовок</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="53"/>
        <source>Track number</source>
        <translation>Номер треку</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="54"/>
        <source>Two-digit track number</source>
        <translation>2-розрядний номер треку</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="55"/>
        <source>Genre</source>
        <translation>Жанр</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="56"/>
        <source>Comment</source>
        <translation>Коментар</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="57"/>
        <source>Composer</source>
        <translation>Композитор</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="58"/>
        <source>Duration</source>
        <translation>Тривалість</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="59"/>
        <source>Disc number</source>
        <translation>Номер диску</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="60"/>
        <source>File name</source>
        <translation>Ім&apos;я файла</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="61"/>
        <source>File path</source>
        <translation>Шлях до файла</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="62"/>
        <source>Year</source>
        <translation>Рік</translation>
    </message>
    <message>
        <location filename="../templateeditor.cpp" line="63"/>
        <source>Condition</source>
        <translation>Умова</translation>
    </message>
</context>
</TS>
